@@ -19,7 +19,7 @@
  *
  * @brief  RFitem struncture and functions.
  * 
- * @author Michał Bąbik <michalb1981@o2.pl>
+ * @author Michal Babik <michal.babik@pm.me>
  */
 #include <err.h>
 #include "defs.h"
@@ -135,7 +135,6 @@ static void
 rfitem_label_set_markup (RFitem *rf_item)
 {
     char s_mark [100];
-    s_mark[0] = '\0';
 
     strcpy (s_mark, "<span font_family=\"monospace\"");
 
@@ -211,11 +210,8 @@ rfitem_new_from_gfile (GFile *g_file)
         free (rf_item);
         err (EXIT_FAILURE, NULL);
     }
-    rf_item->s_org[0] = '\0';
-    rf_item->s_new[0] = '\0';
-    rf_item->s_pth[0] = '\0';
-    s_path  = g_file_peek_path (g_file);
-    s_fn    = get_name_dir_len (s_path, &ui_len);
+    s_path = g_file_peek_path (g_file);
+    s_fn   = get_name_dir_len (s_path, &ui_len);
 
     f_info = g_file_query_info (g_file,
                                 "standard::*",
@@ -256,16 +252,16 @@ rfitem_new_from_gfile (GFile *g_file)
     gtk_widget_set_margin_bottom (rf_item->box, 4);
 
     /* Copy verified file names to original and new file name string */
-    memcpy (rf_item->s_pth, s_path, ui_len);
-    rf_item->s_pth[ui_len] = '\0';
-    strncpy (rf_item->s_org, s_fn, FN_LEN);
-    rf_item->s_org[FN_LEN] = '\0';
     rf_item->org_len = strlen (s_fn);
     rf_item->org_u8len = (size_t) g_utf8_strlen (s_fn, -1);
-    strncpy (rf_item->s_new, s_fn, FN_LEN);
-    rf_item->s_new[FN_LEN] = '\0';
     rf_item->new_len = rf_item->org_len;
     rf_item->new_u8len = rf_item->org_u8len;
+    memcpy (rf_item->s_pth, s_path, ui_len);
+    rf_item->s_pth[ui_len] = '\0';
+    memcpy (rf_item->s_org, s_fn, rf_item->org_len + 1);
+    memcpy (rf_item->s_new, s_fn, rf_item->org_len + 1);
+    /*rf_item->s_org[FN_LEN] = '\0';*/
+    /*rf_item->s_new[FN_LEN] = '\0';*/
     /* rfitem_set_snew_from_sorg (rf_item); */
 
     gtk_box_pack_start (GTK_BOX (rf_item->box), rf_item->check, FALSE, FALSE,0);
@@ -353,19 +349,9 @@ rfitem_set_sorg_from_snew (RFitem *rf_item)
     memcpy (rf_item->s_org, rf_item->s_new, rf_item->new_len + 1);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief      Get s_new value.
- */
-const char *
-rfitem_get_snew (const RFitem *rf_item)
-{
-    return (const char *) rf_item->s_new;
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Set s_new value.
- */
-void
+static void
 rfitem_set_snew (RFitem     *rf_item,
                  const char *val)
 {
@@ -373,44 +359,27 @@ rfitem_set_snew (RFitem     *rf_item,
     memcpy (rf_item->s_new, val, rf_item->new_len+1);
     rf_item->new_u8len = (size_t) g_utf8_strlen (val, -1);
 }
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Get s_org value.
  */
-const char *
-rfitem_get_sorg (const RFitem *rf_item)
-{
-    return (const char *) rf_item->s_org;
-}
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Set s_org value.
- */
-void
+static void
 rfitem_set_sorg (RFitem     *rf_item,
                  const char *val)
 {
     strcpy (rf_item->s_org, val);
 }
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Get s_pth value.
  */
-const char *
-rfitem_get_spth (const RFitem *rf_item)
-{
-    return (const char *) rf_item->s_pth;
-}
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Set s_pth value.
- */
-void
+static void
 rfitem_set_spth (RFitem     *rf_item,
                  const char *val)
 {
     strcpy (rf_item->s_pth, val);
 }
+ */
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Restore original file name button clicked.
@@ -422,25 +391,6 @@ event_click_rev (GtkWidget *widget __attribute__ ((unused)),
     rfitem_entry_restore (rf_item);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Get check button checked value.
- */
-gboolean
-rfitem_get_checked (const RFitem *rf_item)
-{
-    return gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rf_item->check));
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Set check button checked value.
- */
-void
-rfitem_set_checked (RFitem       *rf_item,
-                    const gboolean  b_val)
-{
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (rf_item->check), b_val);
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Invert check item check value
  */
@@ -451,15 +401,6 @@ rfitem_invert_checked (RFitem *rf_item)
             !gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (rf_item->check)));
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Get text from entry.
- */
-const char *
-rfitem_entry_get_text (const RFitem *rf_item)
-{
-    return gtk_entry_get_text (GTK_ENTRY (rf_item->entry));
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Checks if the new entry text is equal to the previous value
  *         and changes it to a new value if it is not.
@@ -472,15 +413,6 @@ rfitem_entry_check_and_update (RFitem     *rf_item,
         gtk_entry_set_text (GTK_ENTRY (rf_item->entry), new_str);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Restore original file name to entry
- */
-void
-rfitem_entry_restore (RFitem *rf_item)
-{
-    gtk_entry_set_text (GTK_ENTRY (rf_item->entry), rf_item->s_org);
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Compare 2 RFitem objects.
  */
@@ -500,41 +432,4 @@ rfitem_compare (const RFitem *rf_item1,
     return i_res;
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Check if RFitem type is a file.
- */
-gboolean
-rfitem_is_file (const RFitem *rf_item)
-{
-    return (rf_item->f_type == G_FILE_TYPE_REGULAR);
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Check if RFitem type is a directory.
- */
-gboolean
-rfitem_is_folder (const RFitem *rf_item)
-{
-    return (rf_item->f_type == G_FILE_TYPE_DIRECTORY);
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Check if RFitem file/dir type is a symlink.
- */
-gboolean
-rfitem_is_symlink (const RFitem *rf_item)
-{
-    return rf_item->b_slink;
-}
-/*----------------------------------------------------------------------------*/
-/**
- * @brief  Check if RFitem file/dir is hidden.
- */
-gboolean
-rfitem_is_hidden (const RFitem *rf_item)
-{
-    return rf_item->b_hidden;
-}
-/*----------------------------------------------------------------------------*/
-
 
