@@ -19,7 +19,7 @@
  *
  * @brief  RFnames struncture and functions.
  *
- * @author Michał Bąbik <michalb1981@o2.pl>
+ * @author Michal Babik <michal.babik@pm.me>
  */
 #include <stdint.h>
 #include <err.h>
@@ -282,15 +282,6 @@ rfnames_add_sfile_to_file_box (RFnames    *rf_names,
     g_object_unref (g_file);
 }
 /*----------------------------------------------------------------------------*/
-/**
- * @brief  Get length of rf_items list
- */
-uint_fast32_t
-rfnames_get_cnt (const RFnames *rf_names)
-{
-    return rf_names->cnt;
-}
-/*----------------------------------------------------------------------------*/
 /**
  * @brief  Select all check items on list.
  */
